@@ -101,6 +101,8 @@ int hci_write_ext_inquiry_response(int dd, uint8_t fec, uint8_t *data, int to);
 int hci_read_simple_pairing_mode(int dd, uint8_t *mode, int to);
 int hci_write_simple_pairing_mode(int dd, uint8_t mode, int to);
 int hci_read_local_oob_data(int dd, uint8_t *hash, uint8_t *randomizer, int to);
+int hci_read_inquiry_transmit_power_level(int dd, int8_t *level, int to);
+int hci_write_inquiry_transmit_power_level(int dd, int8_t level, int to);
 int hci_read_transmit_power_level(int dd, uint16_t handle, uint8_t type, int8_t *level, int to);
 int hci_read_link_supervision_timeout(int dd, uint16_t handle, uint16_t *timeout, int to);
 int hci_write_link_supervision_timeout(int dd, uint16_t handle, uint16_t timeout, int to);
